@@ -54,6 +54,10 @@ if ( $action ) {
 				$recent = (array) get_option( 'recently_activated' );
 				unset( $recent[ $plugin ] );
 				update_option( 'recently_activated', $recent );
+			} else {
+				$recent = (array) get_site_option( 'recently_activated' );
+				unset( $recent[ $plugin ] );
+				update_site_option( 'recently_activated', $recent );
 			}
 
 			if ( isset($_GET['from']) && 'import' == $_GET['from'] ) {
@@ -96,9 +100,18 @@ if ( $action ) {
 
 			if ( ! is_network_admin() ) {
 				$recent = (array) get_option('recently_activated' );
-				foreach ( $plugins as $plugin )
-					unset( $recent[ $plugin ] );
+			} else {
+				$recent = (array) get_site_option('recently_activated' );
+			}
+
+			foreach ( $plugins as $plugin ) {
+				unset( $recent[ $plugin ] );
+			}
+
+			if ( ! is_network_admin() ) {
 				update_option( 'recently_activated', $recent );
+			} else {
+				update_site_option( 'recently_activated', $recent );
 			}
 
 			wp_redirect( self_admin_url("plugins.php?activate-multi=true&plugin_status=$status&paged=$page&s=$s") );
@@ -148,13 +161,6 @@ if ( $action ) {
 
 			@ini_set('display_errors', true); //Ensure that Fatal errors are displayed.
 			// Go back to "sandbox" scope so we get the same errors as before
-			/**
-			 * @param string $plugin
-			 */
-			function plugin_sandbox_scrape( $plugin ) {
-				wp_register_plugin_realpath( WP_PLUGIN_DIR . '/' . $plugin );
-				include( WP_PLUGIN_DIR . '/' . $plugin );
-			}
 			plugin_sandbox_scrape( $plugin );
 			/** This action is documented in wp-admin/includes/plugin.php */
 			do_action( "activate_{$plugin}" );
@@ -172,8 +178,13 @@ if ( $action ) {
 			}
 
 			deactivate_plugins( $plugin, false, is_network_admin() );
-			if ( ! is_network_admin() )
+
+			if ( ! is_network_admin() ) {
 				update_option( 'recently_activated', array( $plugin => time() ) + (array) get_option( 'recently_activated' ) );
+			} else {
+				update_site_option( 'recently_activated', array( $plugin => time() ) + (array) get_site_option( 'recently_activated' ) );
+			}
+
 			if ( headers_sent() )
 				echo "<meta http-equiv='refresh' content='" . esc_attr( "0;url=plugins.php?deactivate=true&plugin_status=$status&paged=$page&s=$s" ) . "' />";
 			else
@@ -201,11 +212,15 @@ if ( $action ) {
 
 			deactivate_plugins( $plugins, false, is_network_admin() );
 
+			$deactivated = array();
+			foreach ( $plugins as $plugin ) {
+				$deactivated[ $plugin ] = time();
+			}
+
 			if ( ! is_network_admin() ) {
-				$deactivated = array();
-				foreach ( $plugins as $plugin )
-					$deactivated[ $plugin ] = time();
 				update_option( 'recently_activated', $deactivated + (array) get_option( 'recently_activated' ) );
+			} else {
+				update_site_option( 'recently_activated', $deactivated + (array) get_site_option( 'recently_activated' ) );
 			}
 
 			wp_redirect( self_admin_url("plugins.php?deactivate-multi=true&plugin_status=$status&paged=$page&s=$s") );
@@ -265,7 +280,7 @@ if ( $action ) {
 
 							// Get plugins list from that folder.
 							if ( $folder_plugins = get_plugins( '/' . $plugin_slug ) ) {
-								foreach( $folder_plugins as $plugin_file => $data ) {
+								foreach ( $folder_plugins as $plugin_file => $data ) {
 									$plugin_info[ $plugin_file ] = _get_plugin_data_markup_translate( $plugin_file, $data );
 									$plugin_info[ $plugin_file ]['is_uninstallable'] = is_uninstallable_plugin( $plugin );
 									if ( ! $plugin_info[ $plugin_file ]['Network'] ) {
@@ -306,11 +321,11 @@ if ( $action ) {
 						foreach ( $plugin_info as $plugin ) {
 							if ( $plugin['is_uninstallable'] ) {
 								/* translators: 1: plugin name, 2: plugin author */
-								echo '<li>', sprintf( __( '<strong>%1$s</strong> by <em>%2$s</em> (will also <strong>delete its data</strong>)' ), esc_html($plugin['Name']), esc_html($plugin['AuthorName']) ), '</li>';
+								echo '<li>', sprintf( __( '<strong>%1$s</strong> by <em>%2$s</em> (will also <strong>delete its data</strong>)' ), $plugin['Name'], $plugin['AuthorName'] ), '</li>';
 								$data_to_delete = true;
 							} else {
 								/* translators: 1: plugin name, 2: plugin author */
-								echo '<li>', sprintf( __('<strong>%1$s</strong> by <em>%2$s</em>' ), esc_html($plugin['Name']), esc_html($plugin['AuthorName']) ), '</li>';
+								echo '<li>', sprintf( __('<strong>%1$s</strong> by <em>%2$s</em>' ), $plugin['Name'], $plugin['AuthorName'] ), '</li>';
 							}
 						}
 						?>
@@ -353,16 +368,22 @@ if ( $action ) {
 				<?php
 				require_once(ABSPATH . 'wp-admin/admin-footer.php');
 				exit;
-			} //Endif verify-delete
-			$delete_result = delete_plugins($plugins);
+			} else {
+				$plugins_to_delete = count( $plugins );
+			} // endif verify-delete
+
+			$delete_result = delete_plugins( $plugins );
 
 			set_transient('plugins_delete_result_' . $user_ID, $delete_result); //Store the result in a cache rather than a URL param due to object type & length
-			wp_redirect( self_admin_url("plugins.php?deleted=true&plugin_status=$status&paged=$page&s=$s") );
+			wp_redirect( self_admin_url("plugins.php?deleted=$plugins_to_delete&plugin_status=$status&paged=$page&s=$s") );
 			exit;
 
 		case 'clear-recent-list':
-			if ( ! is_network_admin() )
+			if ( ! is_network_admin() ) {
 				update_option( 'recently_activated', array() );
+			} else {
+				update_site_option( 'recently_activated', array() );
+			}
 			break;
 	}
 }
@@ -379,14 +400,24 @@ get_current_screen()->add_help_tab( array(
 'title'		=> __('Overview'),
 'content'	=>
 	'<p>' . __('Plugins extend and expand the functionality of WordPress. Once a plugin is installed, you may activate it or deactivate it here.') . '</p>' .
-	'<p>' . sprintf(__('You can find additional plugins for your site by using the <a href="%1$s">Plugin Browser/Installer</a> functionality or by browsing the <a href="%2$s" target="_blank">WordPress Plugin Directory</a> directly and installing new plugins manually. To manually install a plugin you generally just need to upload the plugin file into your <code>/wp-content/plugins</code> directory. Once a plugin has been installed, you can activate it here.'), 'plugin-install.php', 'https://wordpress.org/plugins/') . '</p>'
+	'<p>' . sprintf(
+		/* translators: 1: Plugin Browser/Installer URL, 2: WordPress Plugin Directory URL 3: local plugin directory */
+		__( 'You can find additional plugins for your site by using the <a href="%1$s">Plugin Browser/Installer</a> functionality or by browsing the <a href="%2$s" target="_blank">WordPress Plugin Directory</a> directly and installing new plugins manually. To manually install a plugin you generally just need to upload the plugin file into your %3$s directory. Once a plugin has been installed, you can activate it here.' ),
+		'plugin-install.php',
+		'https://wordpress.org/plugins/',
+		'<code>/wp-content/plugins</code>'
+	) . '</p>'
 ) );
 get_current_screen()->add_help_tab( array(
 'id'		=> 'compatibility-problems',
 'title'		=> __('Troubleshooting'),
 'content'	=>
 	'<p>' . __('Most of the time, plugins play nicely with the core of WordPress and with other plugins. Sometimes, though, a plugin&#8217;s code will get in the way of another plugin, causing compatibility issues. If your site starts doing strange things, this may be the problem. Try deactivating all your plugins and re-activating them in various combinations until you isolate which one(s) caused the issue.') . '</p>' .
-	'<p>' . sprintf( __('If something goes wrong with a plugin and you can&#8217;t use WordPress, delete or rename that file in the <code>%s</code> directory and it will be automatically deactivated.'), WP_PLUGIN_DIR) . '</p>'
+	'<p>' . sprintf(
+		/* translators: WP_PLUGIN_DIR constant value */
+		__( 'If something goes wrong with a plugin and you can&#8217;t use WordPress, delete or rename that file in the %s directory and it will be automatically deactivated.' ),
+		'<code>' . WP_PLUGIN_DIR . '</code>'
+	) . '</p>'
 ) );
 
 get_current_screen()->set_help_sidebar(
@@ -395,15 +426,29 @@ get_current_screen()->set_help_sidebar(
 	'<p>' . __('<a href="https://wordpress.org/support/" target="_blank">Support Forums</a>') . '</p>'
 );
 
+get_current_screen()->set_screen_reader_content( array(
+	'heading_views'      => __( 'Filter plugins list' ),
+	'heading_pagination' => __( 'Plugins list navigation' ),
+	'heading_list'       => __( 'Plugins list' ),
+) );
+
 $title = __('Plugins');
 $parent_file = 'plugins.php';
 
 require_once(ABSPATH . 'wp-admin/admin-header.php');
 
 $invalid = validate_active_plugins();
-if ( !empty($invalid) )
-	foreach ( $invalid as $plugin_file => $error )
-		echo '<div id="message" class="error"><p>' . sprintf(__('The plugin <code>%s</code> has been <strong>deactivated</strong> due to an error: %s'), esc_html($plugin_file), $error->get_error_message()) . '</p></div>';
+if ( ! empty( $invalid ) ) {
+	foreach ( $invalid as $plugin_file => $error ) {
+		echo '<div id="message" class="error"><p>';
+		printf(
+			/* translators: 1: plugin file 2: error message */
+			__( 'The plugin %1$s has been <strong>deactivated</strong> due to an error: %2$s' ),
+			'<code>' . esc_html( $plugin_file ) . '</code>',
+			$error->get_error_message() );
+		echo '</p></div>';
+	}
+}
 ?>
 
 <?php if ( isset($_GET['error']) ) :
@@ -417,8 +462,14 @@ if ( !empty($invalid) )
 	?>
 	<div id="message" class="error"><p><?php echo $errmsg; ?></p>
 	<?php
-		if ( !isset( $_GET['main'] ) && !isset($_GET['charsout']) && wp_verify_nonce($_GET['_error_nonce'], 'plugin-activation-error_' . $plugin) ) { ?>
-	<iframe style="border:0" width="100%" height="70px" src="<?php echo 'plugins.php?action=error_scrape&amp;plugin=' . esc_attr($plugin) . '&amp;_wpnonce=' . esc_attr($_GET['_error_nonce']); ?>"></iframe>
+		if ( ! isset( $_GET['main'] ) && ! isset( $_GET['charsout'] ) && wp_verify_nonce( $_GET['_error_nonce'], 'plugin-activation-error_' . $plugin ) ) {
+			$iframe_url = add_query_arg( array(
+				'action'   => 'error_scrape',
+				'plugin'   => urlencode( $plugin ),
+				'_wpnonce' => urlencode( $_GET['_error_nonce'] ),
+			), admin_url( 'plugins.php' ) );
+		?>
+		<iframe style="border:0" width="100%" height="70px" src="<?php echo esc_url( $iframe_url ); ?>"></iframe>
 	<?php
 		}
 	?>
@@ -431,7 +482,17 @@ if ( !empty($invalid) )
 		if ( is_wp_error($delete_result) ) : ?>
 		<div id="message" class="error notice is-dismissible"><p><?php printf( __('Plugin could not be deleted due to an error: %s'), $delete_result->get_error_message() ); ?></p></div>
 		<?php else : ?>
-		<div id="message" class="updated notice is-dismissible"><p><?php _e('The selected plugins have been <strong>deleted</strong>.'); ?></p></div>
+		<div id="message" class="updated notice is-dismissible">
+			<p>
+				<?php
+				if ( 1 == (int) $_GET['deleted'] ) {
+					_e( 'The selected plugin has been <strong>deleted</strong>.' );
+				} else {
+					_e( 'The selected plugins have been <strong>deleted</strong>.' );
+				}
+				?>
+			</p>
+		</div>
 		<?php endif; ?>
 <?php elseif ( isset($_GET['activate']) ) : ?>
 	<div id="message" class="updated notice is-dismissible"><p><?php _e('Plugin <strong>activated</strong>.') ?></p></div>
@@ -442,7 +503,7 @@ if ( !empty($invalid) )
 <?php elseif (isset($_GET['deactivate-multi'])) : ?>
 	<div id="message" class="updated notice is-dismissible"><p><?php _e('Selected plugins <strong>deactivated</strong>.'); ?></p></div>
 <?php elseif ( 'update-selected' == $action ) : ?>
-	<div id="message" class="updated notice is-dismissible"><p><?php _e('No out of date plugins were selected.'); ?></p></div>
+	<div id="message" class="updated notice is-dismissible"><p><?php _e('All selected plugins are up to date.'); ?></p></div>
 <?php endif; ?>
 
 <div class="wrap">
