@@ -97,6 +97,9 @@ if ( ! CUSTOM_TAGS ) {
 			'src' => true,
 		),
 		'b' => array(),
+		'bdo' => array(
+			'dir' => true,
+		),
 		'big' => array(),
 		'blockquote' => array(
 			'cite' => true,
@@ -1577,6 +1580,19 @@ function wp_kses_post( $data ) {
 	return wp_kses( $data, 'post' );
 }
 
+/**
+ * Navigates through an array, object, or scalar, and sanitizes content for
+ * allowed HTML tags for post content.
+ *
+ * @since 4.4.2
+ *
+ * @param mixed $value The array or string to filter.
+ * @return mixed $value The filtered content.
+ */
+function wp_kses_post_deep( $data ) {
+	return map_deep( $data, 'wp_kses_post' );
+}
+
 /**
  * Strips all of the HTML in the content.
  *
@@ -1694,10 +1710,10 @@ function safecss_filter_attr( $css, $deprecated = '' ) {
 	'border-right-style', 'border-right-width', 'border-spacing', 'border-style', 'border-top',
 	'border-top-color', 'border-top-style', 'border-top-width', 'border-width', 'caption-side',
 	'clear', 'cursor', 'direction', 'font', 'font-family', 'font-size', 'font-style',
-	'font-variant', 'font-weight', 'height', 'letter-spacing', 'line-height', 'margin-bottom',
+	'font-variant', 'font-weight', 'height', 'min-height','max-height' , 'letter-spacing', 'line-height', 'margin-bottom',
 	'margin-left', 'margin-right', 'margin-top', 'overflow', 'padding', 'padding-bottom',
 	'padding-left', 'padding-right', 'padding-top', 'text-decoration', 'text-indent', 'vertical-align',
-	'width' ) );
+	'width', 'min-width', 'max-width' ) );
 
 	if ( empty($allowed_attr) )
 		return $css;
